﻿package jp.or.cute.sangokushi;

import jp.or.cute.sangokushi.httpclient.HttpClient;
import jp.or.cute.sangokushi.httpclient.HttpCommand;
import jp.or.cute.sangokushi.httpclient.HttpRunnable;
import jp.or.cute.sangokushi.httpclient.InitializeCommand;
import jp.or.cute.sangokushi.httpclient.LoginCommand;
import jp.or.cute.sangokushi.httpclient.ResponceHandler;
import android.app.Activity;
import android.app.AlertDialog;
import android.content.Intent;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.os.Message;
import android.view.View;
import android.widget.EditText;
import android.widget.ImageButton;
import android.widget.Toast;

/**
 * 初期設定画面用アクティビティー
 *
 * @author non
 * @author iST
 * @version 0.1
 * @since 2010/05/01
 */

public class Initialization extends Activity implements View.OnClickListener, LocationListener {

	private ImageButton mPresetButton;
	private ImageButton mLoginButton;
	private EditText mUserNameTextBox;
	private LocationManager mLocationManager;
	private double mLatitude;
	private double mLongitude;

    private ResponceHandler mPresetHandler = new ResponceHandler(){
    	public void handleMessage(Message msg){
    		super.handleMessage(msg);
    		if(this.isError()){
    			String message = "登録時にエラーが発生しました。"; 
    			//if(this.getErrorCode() == ResponceHandler.ERROR_CODE_INIT_DUPLICATION_USERNAME){
    			if(this.getErrorCode().equals(ResponceHandler.ERROR_CODE_INIT_DUPLICATION_USERNAME)){
        			message = "ユーザー名は既に利用されています。別なユーザー名を指定して下さい";     				
    			}
    			Toast.makeText(Initialization.this, message, Toast.LENGTH_LONG).show();
    			return;
    		}
    		String[] responces = ResponceHandler.splitResponceParts(this.getResponceArray()[1]);
    		String[] responces2_for_sessionID = ResponceHandler.splitResponceParts(this.getResponceArray()[0]);
    		if(responces.length == 3){
    			/**
    			 * SessionID運用に伴うログインNG修正 
    			 * akifumi3 2010.05.12
    			 */
    			//Ud474bcd73,0fdcfbd07a893ffec59ff2c2790b7a7f,1,魏
    			//[U7ee62fc81, 3, 蜀]
    			SangokushiPreferences pref = new SangokushiPreferences(Initialization.this);
	    		//SessionID保存
    			//pref.setSessionID(responces[1]);
    			pref.setSessionID(responces2_for_sessionID[2]);
    			
	    		
	    		//ユーザーID、ユーザー名
    			pref.setUserID(responces[0]);
    			pref.setUserName(mUserNameTextBox.getText().toString());
	    		
	    		//所属国ID、設定
    			//pref.setCountryID(responces[2]);
    			pref.setCountryID(responces[1]);
	    		
	    		String message = "登録しました。「参加する」をタップして下さい。";
	    		Toast.makeText(Initialization.this, message, Toast.LENGTH_LONG).show();
    		}
    	}
    };

    private ResponceHandler mLoginHandler = new ResponceHandler(){
    	public void handleMessage(Message msg){
    		super.handleMessage(msg);
    		if(this.isError()){
    			String message = "ログイン時にエラーが発生しました。"; 
    			Toast.makeText(Initialization.this, message, Toast.LENGTH_LONG).show();
    			return;
    		}
    		//ロビー画面
	    	try{
				Intent intent = new Intent(Initialization.this, Lobby.class);
				//intent.setFlags(Intent.FLAG_ACTIVITY_REORDER_TO_FRONT);
				startActivityForResult(intent, SangokushiPreferences.RESULT_LOBBY);
	    	}catch(Exception e){
	    		e.printStackTrace();
			}
    	}
    };

    
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.initialization);

		mLocationManager = (LocationManager) getSystemService(LOCATION_SERVICE);
		
	}
	@Override
	protected void onDestroy() {
        if (mLocationManager != null) {
            mLocationManager.removeUpdates(this);
        }
		super.onDestroy();
	}

	@Override
	protected void onPause() {
        if (mLocationManager != null) {
            mLocationManager.removeUpdates(this);
        }
        super.onPause();
	}

	@Override
	protected void onResume() {
		mPresetButton = (ImageButton) findViewById(R.id.presetBtn);
		mPresetButton.setOnClickListener(this);
		mLoginButton = (ImageButton) findViewById(R.id.loginBtn);
		mLoginButton.setOnClickListener(this);
		mUserNameTextBox = (EditText) findViewById(R.id.edittext_name);
		
        if (mLocationManager != null) {
            mLocationManager.requestLocationUpdates(
                LocationManager.GPS_PROVIDER,
                0,
                0,
                this);
        }
        
		super.onResume();		
	}

	@Override
	public void onClick(View v) {
		SangokushiPreferences pref;
		if(v.equals(this.mPresetButton)){
			//ユーザー名登録、所属国決定
			//ユーザー名チェック
			if(mUserNameTextBox.getText() == null){
				AlertDialog.Builder alertDialog = new AlertDialog.Builder(Initialization.this);
				alertDialog.setTitle("エラー");
				alertDialog.setMessage("ユーザー名を入力して下さい");
				alertDialog.show();
				return;
			}
			//ユーザー名、GPS情報送信
			pref = new SangokushiPreferences(Initialization.this);
			InitializeCommand command = new InitializeCommand(HttpCommand.POST, pref.getSessionID());
			command.setParam("un", mUserNameTextBox.getText().toString());
			command.setParam("lat", String.valueOf(mLatitude));
			command.setParam("lon", String.valueOf(mLongitude));
			HttpClient httpclient = HttpClient.getInstance();
			httpclient.setHttpCommand(command);
			HttpRunnable runnable = new HttpRunnable(mPresetHandler, httpclient);
			new Thread(runnable).start();
			
			
		}else if(v.equals(this.mLoginButton)){
			//登録
			//ユーザーIDが無い場合はメッセージ
			pref = new SangokushiPreferences(Initialization.this);
			if(pref.getUserID() == null){
				String message = "ユーザー名を登録して下さい。"; 
				Toast.makeText(Initialization.this, message, Toast.LENGTH_LONG).show();
				return;
			}
			//ログイン処置
			LoginCommand command = new LoginCommand(HttpCommand.POST, pref.getSessionID());
			command.setParam("userid", pref.getUserID());
			HttpClient httpclient = HttpClient.getInstance();
			httpclient.setHttpCommand(command);
			HttpRunnable runnable = new HttpRunnable(mLoginHandler, httpclient);
			new Thread(runnable).start();
		}
	}
	@Override
	public void onLocationChanged(Location location) {
		mLatitude = location.getLatitude();
		mLongitude = location.getLongitude();
	}
	@Override
	public void onProviderDisabled(String provider) {
		mLatitude = 0d;
		mLongitude = 0d;
	}
	@Override
	public void onProviderEnabled(String provider) {
		// TODO Auto-generated method stub
		
	}
	@Override
	public void onStatusChanged(String provider, int status, Bundle extras) {
		// TODO Auto-generated method stub
		
	}



}
