package jp.or.cute.sangokushi;

import java.io.InputStream;
import java.net.URI;

import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.json.JSONException;
import org.json.JSONObject;

import jp.or.cute.sangokushi.httpclient.HttpClient;
import jp.or.cute.sangokushi.httpclient.AuthenticateCommand;
import jp.or.cute.sangokushi.httpclient.HttpCommand;

import jp.or.cute.sangokushi.httpclient.HttpRunnable;

import jp.or.cute.sangokushi.model.Player;

import jp.or.cute.sangokushi.twitter.TwitterOAuth;
import jp.or.cute.sangokushi.twitter.TwitterOperator;
import android.app.Activity;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.media.MediaPlayer;
import android.os.AsyncTask;
import android.os.Bundle;
import android.os.Handler;
import android.os.Message;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.View.OnClickListener;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.Button;
import android.widget.ImageView;
import android.widget.Toast;

/**
 * オープニング画面用アクティビティー
 * @author non
 * @author iST
 * @version 0.1
 * @since 2010/03/26
 */
public class Opening extends Activity {
	public static final String PREFS_KEY_USERINFO = "PrefsUserInfo";
	public static final String PREFS_KEY_TWITTERINFO = "PrefsTwitterInfo";
	
    public static final int RESULT_OAUTH = 1001;
    public static final int RESULT_INIT = 1002;
    public static final int RESULT_LOBBY = 1003;
    
    //通信用クライアント
    HttpClient mHttpClient;
    
	//TwitterAPI制御
	private TwitterOperator mOperator;
	//スタートボタン
	private Button mStartButton;
	private Button mTwitterButton;
	private Button mLobbyButton;
	
	private ProgressDialog mProgress;
	//バックグラウンド再生プレイヤー
	private MediaPlayer mMediaPlayer;
	//プレイヤー
	Player mPlayer;

	/*
	 * 認証処理のハンドラ
	 * TwitterCredentialRunnableからsendされる
	 */
    private Handler mAuthenticateHandler = new Handler(){
    	public void handleMessage(Message msg){
    		JSONObject json = (JSONObject) msg.obj;
    		if(json != null){
    			//サーバーへ認証情報（TwitterID）を送信し、ゲーム側の認証を行う
    			authenticateServer(json);
    		}else{
    			//認証がとおらなければTwitter認証画面へ遷移
    			//startOAuth();
    			startHttpClient();
    		}
    	}
    };
    
    
    private void startHttpClient(){
    	try{
			Intent intent = new Intent(this, TwitterOAuth.class);
			//intent.setFlags(Intent.FLAG_ACTIVITY_REORDER_TO_FRONT);
			startActivityForResult(intent, RESULT_OAUTH);
    	}catch(Exception e){
    		e.printStackTrace();
		}
    }
    
    
    /*
     * ゲームサーバーへの登録・認証のハンドラ
     */
    private Handler mGameAuthenticateHandler = new Handler(){
    	public void handleMessage(Message msg){
    		JSONObject json = (JSONObject) msg.obj;

    		try {
    			if(json != null){
    				JSONObject account = json.getJSONObject("account");
    	    		//スタートボタン表示
    				mStartButton.setText(getString(R.string.start_button));
    				mStartButton.setEnabled(true);

        			String image_path = account.getString("profile_image_url");
    				downloadTwitterImage(image_path);
    			}
			} catch (JSONException e1) {
				e1.printStackTrace();
			}
    		
    		if(mProgress != null){
    			mProgress.dismiss();
    		}
    		
    		if(mMediaPlayer != null && mMediaPlayer.isPlaying()){
    			mMediaPlayer.stop();
    		}
    	}
    };

	//Twitter画像取得、表示
    private void downloadTwitterImage(String uri){
    	DownloadImageTask task = new DownloadImageTask();
    	task.execute(uri);
    }
    
    /*
     * TODO
     * Lobby遷移 @akifumi3
     * 一時的にロビーへ遷移
     * Openingができたら削除します
     */
    private void startLobby(){
    	try{
			Intent intent = new Intent(this, Lobby.class);
			//intent.setFlags(Intent.FLAG_ACTIVITY_REORDER_TO_FRONT);
			startActivityForResult(intent, RESULT_LOBBY);
    	}catch(Exception e){
    		e.printStackTrace();
		}
    }
    
    private void startInitialize(){
    	try{
			Intent intent = new Intent(this, Initialization.class);
			startActivityForResult(intent, RESULT_INIT);
    	}catch(Exception e){
    		e.printStackTrace();
		}
    }
    
    
    @Override
    public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		
		setContentView(R.layout.opening);
		
		//オープニングアニメーション
		ImageView logo = (ImageView)findViewById(R.id.logo);
		Animation anim = AnimationUtils.loadAnimation(this, R.anim.logo_scale);
		logo.startAnimation(anim);
		
		//mp3追加
		mMediaPlayer = MediaPlayer.create(this, R.raw.bgm);
		mMediaPlayer.setLooping(true);

		//通信クライアント
		mHttpClient = HttpClient.getInstance();
		//スタートボタンは認証終了まで非表示
		mStartButton = (Button)findViewById(R.id.start_button);
		//mStartButton.setEnabled(false);
		mTwitterButton = (Button)findViewById(R.id.twitter_button);

		mLobbyButton = (Button)findViewById(R.id.lobby_button);
		mLobbyButton.setOnClickListener(new OnClickListener() {  
			@Override
			public void onClick(View v) {
				startLobby();
			}  
        });  

		//保存している情報によって遷移を決定
		int startBtnTitle = R.string.title_start;
        //ゲームプレイヤー情報
		mPlayer = new Player(this);
		if(mPlayer.getUserID() == null){
			startBtnTitle = R.string.title_initialization;
		}
		mStartButton.setText(startBtnTitle);
		mStartButton.setOnClickListener(new OnClickListener() {  
			@Override
			public void onClick(View v) {
				if(mPlayer.getUserID() == null){
					//初期設定画面へ
					startInitialize();
				}else{
					//ロビー画面へ
					startLobby();
				}
			}  
        });  
		if(mPlayer.getUserName() != null){
			Toast.makeText(this, "ようこそ" + mPlayer.getUserName() + "様", Toast.LENGTH_LONG).show();
		}

		//Twitter認証チェック
		//Opening画面表示中にTwitterの認証情報を確認させる
		mOperator = new TwitterOperator(this);
		if(mOperator.getTwitterToken() == null){
			mTwitterButton.setOnClickListener(new OnClickListener() {  
				@Override
				public void onClick(View v) {
					mOperator.asyncGetCredential(mAuthenticateHandler);
				}  
	        });  
		}else{
			mTwitterButton.setEnabled(false);
		}
    }
    
    @Override
	protected void onResume() {
		super.onResume();
		if(mMediaPlayer != null){
			mMediaPlayer.start();
		}
	}
    
    @Override
	protected void onPause() {
		super.onPause();
		if(mMediaPlayer != null){
			mMediaPlayer.stop();
		}
	}

	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		super.onCreateOptionsMenu(menu);
		
		menu.add(0,10,0, getText(R.string.menu_reset_userstate));
		
		return true;
	}

	@Override
	public boolean onMenuItemSelected(int featureId, MenuItem item) {
		super.onMenuItemSelected(featureId, item);
		
		switch(item.getItemId()){
		case 10:
			String msg = (String) getText(R.string.menu_reset_userstate_comlplatemessage);
			//SharedPreferencesに保存している情報を消去
			SangokushiPreferences pref = new SangokushiPreferences(this);
			if(pref.getUserID() == null || pref.getUserID().length() == 0){
				msg = (String) getText(R.string.menu_reset_userstate_notregistered);
			}else{
	    		//SessionID削除
				pref.removeValue(SangokushiPreferences.SESSION_ID);
	    		//ユーザーID、ユーザー名
				pref.removeValue(SangokushiPreferences.USER_ID);
				pref.removeValue(SangokushiPreferences.USER_NAME);
	    		
	    		//所属国ID、設定
				pref.removeValue(SangokushiPreferences.COUNTRY_ID);
			}
			Toast.makeText(this, msg, Toast.LENGTH_LONG).show();
			break;
		}
		
		return true;
	}

	/*
     * Twitter認証
     */
    private void startOAuth(){
    	try{
			Intent intent = new Intent(this, TwitterOAuth.class);
			//intent.setFlags(Intent.FLAG_ACTIVITY_REORDER_TO_FRONT);
			startActivityForResult(intent, RESULT_OAUTH);
    	}catch(Exception e){
    		e.printStackTrace();
		}
    }

	@Override
	protected void onActivityResult(int requestCode, int resultCode, Intent data) {
		super.onActivityResult(requestCode, resultCode, data);
		if(requestCode == RESULT_OAUTH){
			//認証用Activity（TwitterOAuth）からの戻り
			if(resultCode == RESULT_OK){
				mTwitterButton.setEnabled(false);
				//認証OKなので、サーバーにTwitterIDを送信して必要な情報を取得する
				//authenticateServer();
			}else{
//				//認証NGなので、認証ボタンを表示
//    			mStartButton.setText(getString(R.string.authenticate_button));
//    			mStartButton.setEnabled(true);				
			}
		}
	}
	
	/*
	 * Twitterの認証情報を使って、ゲームサーバーへ認証を行う
	 * 新規の場合はゲームサーバーにTwitterIDとユーザー情報を登録
	 * 既に登録されている場合は、TwitterIDをKeyとして情報を取得
	 */
	private void authenticateServer(JSONObject json){
		String screen_name = json.optString("screen_name", (String) getString(R.string.bad_value));
		String twitter_id = json.optString("id", (String) getString(R.string.bad_value));
		//フォローしている
		int friends_count = 0;
		try {
			friends_count = json.getInt("friends_count");
		} catch (JSONException e) {
			e.printStackTrace();
		}
		//フォローされている
		int followers_count = 0;
		try {
			followers_count = json.getInt("followers_count");
		} catch (JSONException e) {
			e.printStackTrace();
		}
		//Image
		String image = "";
		try {
			image = json.getString("profile_image_url");
		} catch (JSONException e) {
			e.printStackTrace();
		}
		//取得した情報を保存
        //認証情報取得
		SharedPreferences settings = getSharedPreferences(TwitterOperator.PREFS, Context.MODE_PRIVATE);
		SharedPreferences.Editor editor = settings.edit();
		if(twitter_id == null) {
			editor.remove(TwitterOperator.USER_TWITTER_ID);
		}
		else {
			editor.putString(TwitterOperator.USER_TWITTER_ID, twitter_id);
		}
		if(screen_name == null) {
			editor.remove(TwitterOperator.USER_TWITTER_NAME);
		}
		else {
			editor.putString(TwitterOperator.USER_TWITTER_NAME, screen_name);
		}

		//サーバーにID,NAMEを送信して認証
		mProgress = ProgressDialog.show(this, 
				getText(R.string.auth_progress_title), 
				getText(R.string.auth_progress_text), 
				true,
				false);
		String user_token = "";
		String user_secret = "";
		if(settings.contains(TwitterOperator.USER_TOKEN) && settings.contains(TwitterOperator.USER_SECRET)) {
			user_token = settings.getString(TwitterOperator.USER_TOKEN, null);
			user_secret = settings.getString(TwitterOperator.USER_SECRET, null);
			if(!(user_token == null || user_secret == null)) {
				SangokushiPreferences pref = new SangokushiPreferences(this);
				HttpCommand command = new AuthenticateCommand(HttpCommand.POST, pref.getSessionID());
				command.setParam("oauth_token", user_token);
				command.setParam("oauth_verifier", user_secret);
				command.setParam("twitter_id", twitter_id);
				if(mHttpClient == null){
					mHttpClient = HttpClient.getInstance();
				}
				mHttpClient.setHttpCommand(command);
				
				HttpRunnable runnable = new HttpRunnable(mGameAuthenticateHandler, mHttpClient);
				new Thread(runnable).start();
				return;
			}
		}
		// TODO 認証情報が無いのでサーバーへアクセスしない
		//      エラー表示し、再度認証を促すメッセージを表示
		
	}
	
	private void setResultImage(Bitmap image){
		ImageView view = (ImageView) findViewById(R.id.twitter_image);
		view.setImageBitmap(image);
		view.setVisibility(ImageView.VISIBLE);
	}
	/*
	 * 分かりやすいようにTwitter画像を取得して表示
	 * 
	 */
	private class DownloadImageTask extends AsyncTask<String, Integer, Bitmap> {
	    private DefaultHttpClient mClient;
	    private HttpGet mGetMethod;
	    
	    private Bitmap downloadImage(String uri) {
	        try {
	            mGetMethod.setURI(new URI(uri));
	            HttpResponse resp = mClient.execute(mGetMethod);
	            if (resp.getStatusLine().getStatusCode() < 400) {
	                InputStream is = resp.getEntity().getContent();
	                Bitmap bit = createBitmap(is);
	                is.close();
	                return bit;
	            }
	        } catch (Exception e) {
	            e.printStackTrace();
	        }
	        return null;
	    }
	 
	    private Bitmap createBitmap(InputStream is) {
	        return BitmapFactory.decodeStream(is);
	    }
	    
		@Override
		protected void onPreExecute() {
	        mClient = new DefaultHttpClient();
	        mGetMethod = new HttpGet();
		}	    
	    //バックグラウンドで画像をダウンロードする
	    @Override
	    protected Bitmap doInBackground(String... params) {
	        String uri = params[0];
	        return downloadImage(uri);
	    }
	 
	    //画像を描画する
	    @Override
	    protected void onPostExecute(Bitmap result) {
	        Opening.this.setResultImage(result);
	    }
	 }
}