package jp.or.cute.sangokushi.model;

import jp.or.cute.sangokushi.R;
import jp.or.cute.sangokushi.SangokushiPreferences;
import jp.or.cute.sangokushi.view.MapView;
import android.content.Context;
import android.content.SharedPreferences;
import android.content.res.Resources;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.util.Log;

/**
 * プレイヤー
 * @author iST
 * @author Takki
 * @version 0.1.1
 * @since 2010/04/06
 * @change 2010/05/05
 */
public class Player {
	//設定情報key
	public static final String PREFS = "OpenSangokushiPrefsPlayerFile";
	public static final String USER_NAME = "user_name";
	public static final String USER_ID = "user_id";
	
	private static final int GO = 1;
	private static final int GI = 0;
	private static final int SYUKU = 2;

	public static final String GENERAL = "s";
	public static final String	COMMANDER = "b";
	public static final String USER = "u";
	
	private Context mContext;
	//設定情報
	private SharedPreferences mSettings;
	private SangokushiPreferences mPreferences;
	
	private String mCommanderClass = this.USER;
	private String mName;
	private int mPower = 0;
	private int mMobilty = 0;
	private int mCurrentMapX = 0;
	private int mCurrentMapY = 0;
	
	private static final int cell_x = 45;
	private static final int cell_y = 45;
	// プレーヤー本人
	private boolean mMySelf = false;

	//
	private int mCountry = -1;

	public void setMySelf() {
		mMySelf = true;
	}
	
	public boolean getMySelf() {
		return mMySelf;
	}
	
	public void setCountry(int country) {
		mCountry = country;
	}

	public void setInfo(int power,int mobilty,String cmdClass,int country,int cell)
	{
//		Log.d("Player","setInfo(power="+Integer.toString(power)+",cmdClass="+cmdClass+",country="+Integer.toString(country)+",cell="+Integer.toString(cell)+")");
		cell--;
		int x = cell % cell_x;
		int y = cell / cell_y;
		this.mMapX = x;
		this.mMapY = y;
		this.mCountry = country;
		this.mPower = power;
		this.mMobilty = mobilty;
		this.mCommanderClass = cmdClass;
	}

	public String getCountry() {
		switch(mCountry) {
		case GO:
			return "GO";
		case GI:
			return "GI";
		case SYUKU:
			return "SYUKU";
		}
		return "";
	}

	public int getCountryID() {
		return mCountry;
	}

	public static String getCountryName(int country) {
		switch(country) {
		case GO:
			return "呉";
		case GI:
			return "魏";
		case SYUKU:
			return "蜀";
		}
		return "";
	}
	
	public String getCountryName() {
		switch(mCountry) {
		case GO:
			return "呉";
		case GI:
			return "魏";
		case SYUKU:
			return "蜀";
		}
		return "";
	}
	
	public String getName() {
		return mName;
	}

	public void setName(String name) {
		mName = name;
	}
	
	//ユーザーID
	public String getUserID() {
		if(mPreferences == null){
			mPreferences = new SangokushiPreferences(mContext);
		}
		return mPreferences.getUserID();
	}
	
	// 兵力
	public int getPower() {
		return mPower;
	}
	
	public String getCommanderID()
	{
		return this.mCommanderClass;
	}
	
	public String getCommanderClass() {
		Log.d("getCommanderClass","class=\""+mCommanderClass+"\"");
		if (this.mCommanderClass.equals(GENERAL)) {
			//return this.mContext.getString(R.string.general);
			return "総大将";
		}
		else if (this.mCommanderClass.equals(COMMANDER))
		{
			//return this.mContext.getString(R.string.commander);
			return "武将";
		} else {
			//return this.mContext.getString(R.string.game_user);
			return "隊長";
		}
	}
	
	public void setUserID(String id) {
		SharedPreferences.Editor editor = mSettings.edit();
		if(id == null) {
			editor.remove(USER_ID);
		}
		else {
			editor.putString(USER_ID, id);
		}
	}
	//ユーザー名
	public String getUserName() {
		if(mPreferences == null){
			mPreferences = new SangokushiPreferences(mContext);
		}
		return mPreferences.getUserName();
		
//		if(mSettings != null && mSettings.contains(USER_NAME)){
//			return mSettings.getString(USER_NAME, null);
//		}
//		return null;
	}
	public void setUserName(String name) {
		SharedPreferences.Editor editor = mSettings.edit();
		if(name == null) {
			editor.remove(USER_NAME);
		}
		else {
			editor.putString(USER_NAME, name);
		}
	}
	
	//移動可能範囲
	private int mMoveArea = 5;
	
	//マップ上の位置
	public int mMapX = 4;
	public int mMapY = 7;
	
	private Bitmap mMapchipUp;
	private Bitmap mMapchipDown;
	private Bitmap mMapchipUpKing;
	private Bitmap mMapchipDownKing;
	
	public Player(Context context){
		mContext = context;
		mName = "";
		this.initialize();
	}

	public Player(Context context, String name){
		mContext = context;
		mName = name;
		this.initialize();
	}

	public void setPoint(int x,int y){
		mMapX = x;
		mMapY = y;
	}
	/*
	 * 初期化処理
	 */
	private void initialize(){
        Resources r=mContext.getResources();
        mMapchipUp = BitmapFactory.decodeResource(r,R.drawable.player); 
        mMapchipDown = BitmapFactory.decodeResource(r,R.drawable.player_back); 
        mMapchipUpKing = BitmapFactory.decodeResource(r,R.drawable.king); 
        mMapchipDownKing = BitmapFactory.decodeResource(r,R.drawable.king_back); 
        //認証情報取得
		mSettings = mContext.getSharedPreferences(Player.PREFS, Context.MODE_PRIVATE);
	}
	
	/*
	 * プレイヤー描画
	 */
	public void draw(Canvas canvas, float scale, int mapLeft, int mapTop){
		int x = -1;
		int y = -1;
		
		Bitmap mMapchip = mMapchipUp;
		if (this.mCommanderClass == this.GENERAL) {
			
		} else {
			
		}
		
		
		mCurrentMapX = mapLeft;
		mCurrentMapY = mapTop;
		if(mapLeft <= mMapX && (mapLeft+15) >= mMapX){
			x = MapView.CHIP_W * (mMapX - mapLeft);
		}
		if(mapTop <= mMapY && (mapTop+15) >= mMapY){
			y = MapView.CHIP_H * (mMapY - mapTop);
		}

		if(x >= 0 && y >= 0){
			if(scale != 1.0f){
				canvas.drawBitmap(
					Bitmap.createBitmap(mMapchip, 0, 0, (int)(MapView.CHIP_W*scale), (int)(MapView.CHIP_H*scale)),
					x, y, null);
			}else{
				if (this.mCommanderClass.equals(GENERAL))
				{
					canvas.drawBitmap(mMapchipDownKing, x, y, null);
				} else {
					canvas.drawBitmap(mMapchip, x, y, null);
				}
			}
		}
	}
	/*
	 * 全体地図にプレイヤー描画
	 */
	public void drawOnWholeMap(Canvas canvas, int w, int h){
		Paint paint = new Paint();
		if (mMySelf) {
			paint.setColor(Color.RED);
		}
		else {
			switch(mCountry) {
			case GI:
				if (mCommanderClass.equals(this.COMMANDER)) {// == "b") {
					paint.setColor(Color.CYAN);
				}
				else if (this.mCommanderClass.equals(this.GENERAL)) {//s") {
					paint.setColor(Color.CYAN);
				}
				else {
					paint.setColor(Color.CYAN);
				}
				break;
			case GO:
				if (mCommanderClass.equals(this.COMMANDER)) {// == "b") {
					paint.setColor(Color.YELLOW);
				}
				else if (this.mCommanderClass.equals(this.GENERAL)) {//=="s") {
					paint.setColor(Color.YELLOW);
				}
				else {
					paint.setColor(Color.YELLOW);
				}
				break;
			case SYUKU:
				if (mCommanderClass.equals(this.COMMANDER)) {// == "b") {
					paint.setColor(Color.WHITE);
				}
				else if (this.mCommanderClass.equals(this.GENERAL)) {// =="s") {
					paint.setColor(Color.WHITE);
				}
				else {
					paint.setColor(Color.WHITE);
				}
				break;
			}
		}
		
		paint.setStyle(Style.FILL);
		int x = mMapX * w;
		int y = mMapY * h; 
		canvas.drawRect(x, y, x + w, y + h, paint);
	}
	
	public int calcDrawArea(int p,int mCurrentMap)
	{
		if (mCurrentMap <= p &&  p <= (mCurrentMap+15))
		{
			return p - mCurrentMap;
		}
		return -1;
	}
	
	/*
	 * 移動可能範囲の描画
	 */
	public void drawMovingArea(Canvas canvas){
		int leftX = calcDrawArea(mMapX-mMoveArea,mCurrentMapX);
		int topY = calcDrawArea(mMapY-mMoveArea,mCurrentMapY);
		int rightX = calcDrawArea(mMapX+1+mMoveArea+1,mCurrentMapX);
		int bottomY = calcDrawArea(mMapY+1+mMoveArea+1,mCurrentMapY);
		
		if (leftX < 0 && rightX > 0) {
			leftX = 0;
		}
		if (leftX > 0 && rightX < 0) {
			rightX = 15;
		}
		if (topY < 0 && bottomY > 0) {
			topY = 0;
		}
		if (topY > 0 && bottomY < 0) {
			bottomY = 15;
		}
		
		if (leftX >= 0 && topY >= 0 && rightX >= 0 && bottomY >= 0) {
			int left = leftX * MapView.CHIP_W;
			int top = topY * MapView.CHIP_H;
			int right = rightX * MapView.CHIP_W;
			int bottom = bottomY * MapView.CHIP_H;
		
			Paint paint = new Paint();
			paint.setColor(Color.RED);
			paint.setAlpha(40);
			paint.setStyle(Style.FILL);
			canvas.drawRect(left, top, right, bottom, paint);
		}
	}
	
	/*
	 * クリックされた処に自分のPlayerがいるかチェックする
	 */
	public boolean hitTest(float pointX, float pointY){
		int left = (mMapX - mCurrentMapX) * MapView.CHIP_W;
		int top = (mMapY - mCurrentMapY) * MapView.CHIP_H;
		int right = left + MapView.CHIP_W;
		int bottom = top + MapView.CHIP_H;
/*		
		Log.d("hitTest","mMapX="+Integer.toString(mMapX)+"|mMapY="+Integer.toString(mMapY));
		Log.d("hitTest","pointX="+Float.toString(pointX)+"|left="+Integer.toString(left)+"|right="+Integer.toString(right));
		Log.d("hitTest","pointY="+Float.toString(pointY)+"|top="+Integer.toString(top)+"|bottom="+Integer.toString(bottom));
*/
		if(left <= pointX && pointX <= right){
			if(top <= pointY && pointY <= bottom){
				return true;
			}
		}
		return false;
	}
}
