package jp.or.cute.sangokushi.twitter;

import jp.or.cute.sangokushi.Opening;
import junit.framework.Assert;
import oauth.signpost.OAuth;
import oauth.signpost.OAuthConsumer;
import oauth.signpost.OAuthProvider;
import oauth.signpost.commonshttp.CommonsHttpOAuthConsumer;
import oauth.signpost.commonshttp.CommonsHttpOAuthProvider;
import oauth.signpost.exception.OAuthCommunicationException;
import oauth.signpost.exception.OAuthExpectationFailedException;
import oauth.signpost.exception.OAuthMessageSignerException;
import oauth.signpost.exception.OAuthNotAuthorizedException;
import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.net.Uri;
import android.os.Bundle;

/*
 * TwitterのOAuth認証
 * 	Twitter認証画面を表示して、認証処理をユーザーに求める
 * 	認証後、Opening画面に遷移する
 * @author iST
 * @version 0.1
 * @since 2010/03/29
 */
public class TwitterOAuth extends Activity {
	private OAuthConsumer mConsumer = null;
	private OAuthProvider mProvider = null;
	
	SharedPreferences mSettings;

	private boolean mInitialOnResume = true;
	
	public void onCreate(Bundle icicle) {
		super.onCreate(icicle);
	
		mConsumer = new CommonsHttpOAuthConsumer(
				TwitterOperator.TWITTER_CONSUMER_KEY, 
				TwitterOperator.TWITTER_CONSUMER_SECRET);
		
		mProvider = new CommonsHttpOAuthProvider (
				TwitterOperator.TWITTER_REQUEST_TOKEN_URL, 
				TwitterOperator.TWITTER_ACCESS_TOKEN_URL,
				TwitterOperator.TWITTER_AUTHORIZE_URL);
		
		mProvider.setOAuth10a(true);
		
		mSettings = this.getSharedPreferences(TwitterOperator.PREFS, Context.MODE_PRIVATE);

		Intent i = this.getIntent();
		if (i.getData() == null) {
			try {
				String authUrl = mProvider.retrieveRequestToken(mConsumer, TwitterOperator.CALLBACK_URI.toString());
				saveRequestInformation(mSettings, mConsumer.getToken(), mConsumer.getTokenSecret());
				this.startActivity(new Intent(Intent.ACTION_VIEW, Uri.parse(authUrl)));
			} catch (OAuthMessageSignerException e) {
				e.printStackTrace();
			} catch (OAuthNotAuthorizedException e) {
				e.printStackTrace();
			} catch (OAuthExpectationFailedException e) {
				e.printStackTrace();
			} catch (OAuthCommunicationException e) {
				e.printStackTrace();
			}
		}
	}

	@Override
	protected void onResume() {
		super.onResume();

		Uri uri = getIntent().getData();
		if (uri != null && TwitterOperator.CALLBACK_URI.getScheme().equals(uri.getScheme())) {
			String token = mSettings.getString(TwitterOperator.REQUEST_TOKEN, null);
			String secret = mSettings.getString(TwitterOperator.REQUEST_SECRET, null);
			//Opening画面に遷移
			Intent i = new Intent(this, Opening.class);
			
			try {
				if(!(token == null || secret == null)) {
					mConsumer.setTokenWithSecret(token, secret);
				}
				String otoken = uri.getQueryParameter(OAuth.OAUTH_TOKEN);
				String verifier = uri.getQueryParameter(OAuth.OAUTH_VERIFIER);

				Assert.assertEquals(otoken, mConsumer.getToken());

				mProvider.retrieveAccessToken(mConsumer, verifier);
				token = mConsumer.getToken();
				secret = mConsumer.getTokenSecret();
				TwitterOAuth.saveAuthInformation(mSettings, token, secret);
				TwitterOAuth.saveRequestInformation(mSettings, null, null);
				i.putExtra(TwitterOperator.USER_TOKEN, token);
				i.putExtra(TwitterOperator.USER_SECRET, secret);
				setResult(RESULT_OK, i);
			} catch (OAuthMessageSignerException e) {
				e.printStackTrace();
			} catch (OAuthNotAuthorizedException e) {
				e.printStackTrace();
			} catch (OAuthExpectationFailedException e) {
				e.printStackTrace();
			} catch (OAuthCommunicationException e) {
				e.printStackTrace();
			} finally {
				startActivity(i);
				finish();
//				finishActivity(Opening.RESULT_OAUTH);
			}
		}else if(mInitialOnResume){
			mInitialOnResume = false;
			return;
		}
		//finish();
		//TwitterOAuth.this.finish();
	}
	
	public static void saveRequestInformation(SharedPreferences settings, String token, String secret) {
		SharedPreferences.Editor editor = settings.edit();
		if(token == null) {
			editor.remove(TwitterOperator.REQUEST_TOKEN);
		}
		else {
			editor.putString(TwitterOperator.REQUEST_TOKEN, token);
		}
		if (secret == null) {
			editor.remove(TwitterOperator.REQUEST_SECRET);
		}
		else {
			editor.putString(TwitterOperator.REQUEST_SECRET, secret);
		}
		editor.commit();
		
	}
	
	public static void saveAuthInformation(SharedPreferences settings, String token, String secret) {
		SharedPreferences.Editor editor = settings.edit();
		if(token == null) {
			editor.remove(TwitterOperator.USER_TOKEN);
		}
		else {
			editor.putString(TwitterOperator.USER_TOKEN, token);
		}
		if (secret == null) {
			editor.remove(TwitterOperator.USER_SECRET);
		}
		else {
			editor.putString(TwitterOperator.USER_SECRET, secret);
		}
		editor.commit();
		
	}
	
}
