package jp.or.cute.sangokushi.view;

import jp.or.cute.sangokushi.dummy.DummyMapData;
import jp.or.cute.sangokushi.model.Player;
import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Paint.Style;
import android.util.AttributeSet;
import android.util.Log;
import android.view.View;

public class WholeMapView extends View{
	int w = 2;
	int h = 2;
	private int[][] map;
	private int[] colors;

	//詳細地図の表示範囲
	private int mAreaX;
	private int mAreaY;
	
	private Bitmap mMap;
	
	private boolean mFirstDraw = false;
	/*
	 * 詳細地図の表示範囲をセットして再描画
	 */
	public void drawArea(int x, int y){
		mAreaX = x;
		mAreaY = y;
		this.invalidate();
	}
	//ゲームプレイヤー
	private Player mPlayer;
	private Player[] mPlayers;
	
	/*
	 * ゲームプレイヤーをセット
	 */
	public void setPlayer(Player player){
		mPlayer = player;
	}

	/*
	 * ゲームプレイヤーをセット
	 */
	public void setPlayers(Player[] players){
		mPlayers = players;
	}
	
	@Override
	protected void onDraw(Canvas canvas) {
		Paint paintBg = new Paint();
		paintBg.setColor(Color.BLACK);
		Paint paint = new Paint();
		paint.setStyle(Style.FILL);
		Paint paintStroke = new Paint();
		paintStroke.setStyle(Style.STROKE);
		paintStroke.setColor(Color.BLACK);
		paintStroke.setStrokeWidth(0);

		super.onDraw(canvas);
		//マップ
		if(map == null){
			map = DummyMapData.createDummyMap();
		}
		//マップカラー
		if(colors == null){
			colors = DummyMapData.getMapColors();
		}
		int m = 1;
		int x = 0;
		int y = 0;
		if(mMap == null){
			mMap = Bitmap.createBitmap(getWidth(), getHeight(), Bitmap.Config.ARGB_8888);
			Canvas mapCanvas = new Canvas(mMap);
			mapCanvas.drawRect(0, 0, getWidth(), getHeight(), paintBg);
			for(int i = 0; i < 60; i++){
				for(int j = 0; j < 60; j++){
					x = i * w;
					y = j * h;
					if((x >= 0 && x < getWidth()) && (y >= 0 && y < getHeight())){
						m = map[i][j]-1;
						paint.setColor(colors[m]);
						mapCanvas.drawRect(x, y, x + w, y + h, paint);
						mapCanvas.drawRect(x, y, x + w, y + h, paintStroke);
					}
				}
			}				
		}
		canvas.drawBitmap(mMap, 0, 0,new Paint());		
		mFirstDraw = true;
		if (mPlayers != null) {
			for (int i=0;i<mPlayers.length;i++) {
				mPlayers[i].drawOnWholeMap(canvas, w,h);
			}
		}
		/*
		//プレイヤー描画
		if(mPlayer != null){
			mPlayer.drawOnWholeMap(canvas, w, h);
		}
*/

		//詳細地図エリア
		paintStroke.setColor(Color.RED);
		canvas.drawRect(mAreaX*w, mAreaY*h, (mAreaX+15)*w, (mAreaY+15)*h, paintStroke);
	}

	public void setMapData(int[][] mapdata){
		map = mapdata;
	}
	public void setMapColors(int[] colorsdata){
		colors = colorsdata;
	}
	public WholeMapView(Context context, AttributeSet attrs, int defStyle) {
		super(context, attrs, defStyle);
		// TODO Auto-generated constructor stub
	}

	public WholeMapView(Context context, AttributeSet attrs) {
		super(context, attrs);
		// TODO Auto-generated constructor stub
	}

	public WholeMapView(Context context) {
		super(context);
		// TODO Auto-generated constructor stub
	}

}
